%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

%if 0%{?!valgrind_arches:1}
%define valgrind_arches %{ix86} x86_64 ppc ppc64 ppc64le s390x armv7hl
%endif

%define major 2
%define libname %mklibname drm %{major}
%define develname %mklibname drm -d

%define kms_major 1
%define libkms %mklibname kms %{kms_major}
%define intel_major 1
%define libintel %mklibname drm_intel %{intel_major}
%define nouveau_major 2
%define libnouveau %mklibname drm_nouveau %{nouveau_major}
%define radeon_major 1
%define libradeon %mklibname drm_radeon %{radeon_major}
%define tegra_major 0
%define libtegra %mklibname drm_tegra %{tegra_major}
%define omap_major 1
%define libomap %mklibname drm_omap %{omap_major}
%define etnaviv_major 1
%define libetnaviv %mklibname drm_etnaviv %{etnaviv_major}
%define exynos_major 1
%define libexynos %mklibname drm_exynos %{exynos_major}
%define freedreno_major 1
%define libfreedreno %mklibname drm_freedreno %{freedreno_major}
%define amdgpu_major 1
%define libamdgpu %mklibname drm_amdgpu %{amdgpu_major}

%define bcond_meson() %{lua: do
  local option = rpm.expand("%{1}")
  local with = rpm.expand("%{?with_" .. option .. "}")
  local value = (with ~= '') and "true" or "false"
  option = option:gsub('_', '-')
  print(string.format("-D%s=%s", option, value))
end}

%bcond_without libkms
%ifarch %{ix86} x86_64
%bcond_without intel
%else
%bcond_with    intel
%endif
%bcond_without radeon
%bcond_without amdgpu
%bcond_without nouveau
%bcond_without vmwgfx
%ifarch %{arm}
%bcond_without omap
%else
%bcond_with    omap
%endif
%ifarch %{arm} aarch64
%bcond_without exynos
%bcond_without freedreno
%bcond_without tegra
%bcond_without vc4
%bcond_without etnaviv
%else
%bcond_with    exynos
%bcond_with    freedreno
%bcond_with    tegra
%bcond_with    vc4
%bcond_with    etnaviv
%endif
%bcond_with    cairo_tests
%bcond_without man_pages
%ifarch %{valgrind_arches}
%bcond_without valgrind
%else
%bcond_with    valgrind
%endif
%bcond_with    freedreno_kgsl
%bcond_without install_test_programs
%bcond_without udev

Name:		libdrm
Summary:        Direct Rendering Manager runtime library
Version:	2.4.107
Release:	%mkrel 3
License:        MIT
Group:		System/Libraries
URL:		http://xorg.freedesktop.org
Source0:	https://dri.freedesktop.org/libdrm/libdrm-%{version}.tar.xz
Source2:	91-drm-modeset.rules

BuildRequires: gcc >= 10.3.0-1

BuildRequires:  meson >= 0.43
BuildRequires:  pkgconfig 
BuildRequires:  automake 
BuildRequires:  autoconf 
BuildRequires:  libtool
BuildRequires:	kernel-userspace-headers >= 3.3.1-1
BuildRequires:	libpthread-stubs
BuildRequires:	x11-util-macros >= 1.0.1
%if !%bootstrap
BuildRequires:  pkgconfig(systemd)
%endif
BuildRequires:	pkgconfig(pciaccess)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	xsltproc
BuildRequires:	docbook-xsl
%if %{with valgrind}
BuildRequires:	pkgconfig(valgrind)
%endif
BuildRequires:	pkgconfig(cunit)
BuildRequires:	pkgconfig(udev)
BuildRequires:	python3-docutils

# Upstream fixes
Patch001:	0001-xf86drm-fix-mem-leak-in-drm_usb_dev_path.patch
Patch002:	0002-intel-sync-ADL-S-PCI-IDs-with-kernel.patch
Patch003:	0003-amdgpu-add-marketing-names-from-21.30.patch
Patch004:	0004-amdgpu-add-new-marketing-name.patch
Patch005:	0005-intel-Sync-pci-ids.patch

# Fedora patches:
# hardcode the 666 instead of 660 for device nodes
Patch1001:	libdrm-make-dri-perms-okay.patch
# remove backwards compat not needed on Fedora
Patch1002:	libdrm-2.4.69-no-bc.patch

Patch0500:	0500-improve-waiting-for-dri-device-to-appear-when-system.patch

%description
Direct Rendering Manager runtime library

%package common
Summary:	Common files for the userspace interface to kernel DRM services
Group:		System/Libraries

%description common
Common files for the userspace interface to kernel DRM services

%package -n	%{libname}
Summary:	Userspace interface to kernel DRM services
Group:		System/Libraries
Provides:	%{name} = %{version}
Requires: %{name}-common

%description -n	%{libname}
Userspace interface to kernel DRM services

%package -n %{libkms}
Summary:  Shared library for KMS
Group:    System/Libraries

%description -n %{libkms}
Shared library for kernel mode setting.

%ifarch %{ix86} x86_64
%package -n	%{libintel}
Summary:	Shared library for Intel kernel DRM services
Group:		System/Libraries
Conflicts:	%{_lib}drm2 < 2.4.5-2

%description -n %{libintel}
Shared library for Intel kernel Direct Rendering Manager services.
%endif

%package -n	%{libnouveau}
Summary:	Shared library for Nouveau kernel DRM services
Group:		System/Libraries

%description -n %{libnouveau}
Shared library for Nouveau kernel Direct Rendering Manager services.

%package -n	%{libradeon}
Summary:	Shared library for Radeon kernel DRM services
Group:		System/Libraries
Conflicts:	%{_lib}drm2 < 2.4.5-2

%description -n %{libradeon}
Shared library for Radeon kernel Direct Rendering Manager services.

%ifarch %arm
%package -n	%{libomap}
Summary:	Shared library for OMAP kernel DRM services
Group:		System/Libraries
Conflicts:	%{_lib}drm2 < 2.4.5-2

%description -n %{libomap}
Shared library for OMAP kernel Direct Rendering Manager services.
%endif

%ifarch %arm aarch64
%package -n	%{libtegra}
Summary:	Shared library for TEGRA kernel DRM services
Group:		System/Libraries

%description -n %{libtegra}
Shared library for TEGRA kernel Direct Rendering Manager services.

%package -n	%{libetnaviv}
Summary:	Shared library for Etnaviv kernel DRM services
Group:		System/Libraries

%description -n %{libetnaviv}
Shared library for Etnaviv kernel Direct Rendering Manager services.

%package -n	%{libexynos}
Summary:	Shared library for Exynos kernel DRM services
Group:		System/Libraries
Conflicts:	%{_lib}drm2 < 2.4.5-2

%description -n %{libexynos}
Shared library for EXYNOS kernel Direct Rendering Manager services.

%package -n	%{libfreedreno}
Summary:	Shared library for Freedreno kernel DRM services
Group:		System/Libraries

%description -n %{libfreedreno}
Shared library for Freedreno kernel Direct Rendering Manager services.
%endif

%package -n	%{libamdgpu}
Summary:	Shared library for AMDGPU kernel DRM services
Group:		System/Libraries

%description -n %{libamdgpu}
Shared library for AMDGPU kernel Direct Rendering Manager services.

%package -n	%{develname}
Summary:        Direct Rendering Manager development package
Group:		Development/X11
Requires:	%{libname} = %{version}
Requires:	%{libkms} = %{version}
%ifarch %{ix86} x86_64
Requires:	%{libintel} = %{version}
%endif
Requires:	%{libnouveau} = %{version}
Requires:	%{libradeon} = %{version}
Requires:	%{libamdgpu} = %{version}
%ifarch %arm
Requires:	%{libomap} = %{version}
%endif
%ifarch %arm aarch64
Requires:	%{libtegra} = %{version}
Requires:	%{libexynos} = %{version}
Requires:	%{libfreedreno} = %{version}
Requires:       %{libetnaviv} = %{version}
%endif
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{mklibname drm 2 -d}
Obsoletes:	drm-nouveau-devel < 2.3.0-2.20090111.2

%description -n	%{develname}
Direct Rendering Manager development package.

%package -n drm-utils
Summary:        Direct Rendering Manager utilities
Group:		System/Base
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n drm-utils
Utility programs for the kernel DRM interface.  Will void your warranty.

%prep
%autosetup -p1

%build
%meson \
  %{bcond_meson libkms}                \
  %{bcond_meson intel}                 \
  %{bcond_meson radeon}                \
  %{bcond_meson amdgpu}                \
  %{bcond_meson nouveau}               \
  %{bcond_meson vmwgfx}                \
  %{bcond_meson omap}                  \
  %{bcond_meson exynos}                \
  %{bcond_meson freedreno}             \
  %{bcond_meson tegra}                 \
  %{bcond_meson vc4}                   \
  %{bcond_meson etnaviv}               \
  %{bcond_meson cairo_tests}           \
  %{bcond_meson man_pages}             \
  %{bcond_meson valgrind}              \
  %{bcond_meson freedreno_kgsl}        \
  %{bcond_meson install_test_programs} \
  %{bcond_meson udev}                  \
  %{nil}
%meson_build

%install
%meson_install
install -Dpm0755 -t %{buildroot}%{_bindir} %{_vpath_builddir}/tests/drmdevice
%if %{with udev}
install -Dpm0644 -t %{buildroot}%{_udevrulesdir} %{S:2}
%endif

# NOTE: We intentionally don't ship *.la files
find %{buildroot} -type f -name "*.la" -delete

# (cg) Note that RH remove r300_reg.h via_3d_reg.h
# and we should perhaps do the same? (previous attempts have not gone well :)

%files common
%{_udevrulesdir}/91-drm-modeset.rules
%{_datadir}/libdrm/amdgpu.ids

%files -n %{libname}
%{_libdir}/libdrm.so.%{major}{,.*}

%files -n %{libkms}
%{_libdir}/libkms.so.%{kms_major}{,.*}

%ifarch %{ix86} x86_64
%files -n %{libintel}
%{_libdir}/libdrm_intel.so.%{intel_major}{,.*}
%endif

%files -n %{libnouveau}
%{_libdir}/libdrm_nouveau.so.%{nouveau_major}{,.*}

%files -n %{libamdgpu}
%{_libdir}/libdrm_amdgpu.so.%{amdgpu_major}{,.*}

%files -n %{libradeon}
%{_libdir}/libdrm_radeon.so.%{radeon_major}{,.*}

%ifarch %arm
%files -n %{libomap}
%{_libdir}/libdrm_omap.so.%{omap_major}{,.*}
%endif

%ifarch %arm aarch64
%files -n %{libtegra}
%{_libdir}/libdrm_tegra.so.%{tegra_major}{,.*}

%files -n %{libetnaviv}
%{_libdir}/libdrm_etnaviv.so.%{etnaviv_major}{,.*}

%files -n %{libexynos}
%{_libdir}/libdrm_exynos.so.%{exynos_major}{,.*}

%files -n %{libfreedreno}
%{_libdir}/libdrm_freedreno.so.%{freedreno_major}{,.*}
%endif

%files -n drm-utils
%{_bindir}/amdgpu_test
%{_bindir}/drmdevice
%{_bindir}/modetest
%{_bindir}/modeprint
%{_bindir}/vbltest
%{_bindir}/kmstest
%{_bindir}/kms-steal-crtc
%{_bindir}/kms-universal-planes
%exclude %{_bindir}/exynos*
%exclude %{_bindir}/etnaviv*
%exclude %{_bindir}/drmsl
%exclude %{_bindir}/hash
%exclude %{_bindir}/proptest
%exclude %{_bindir}/random

%files -n %{develname}
%{_includedir}/libdrm
%{_includedir}/libkms
%{_includedir}/*.h
%ifarch %arm
%{_includedir}/omap/*.h
%endif
%ifarch %arm aarch64
%{_includedir}/exynos/*.h
%{_includedir}/freedreno/*.h
%endif
%{_libdir}/libdrm*.so
%{_libdir}/libkms.so
%{_libdir}/pkgconfig/libdrm*.pc
%{_libdir}/pkgconfig/libkms*.pc
%{_mandir}/man3/drmAvailable.3*
%{_mandir}/man3/drmHandleEvent.3*
%{_mandir}/man3/drmModeGetResources.3*
%{_mandir}/man7/drm-kms.7*
%{_mandir}/man7/drm-memory.7*
%{_mandir}/man7/drm.7*


%changelog
* Sat Oct 16 2021 tmb <tmb> 2.4.107-3.mga8
+ Revision: 1751782
- xf86drm: fix mem leak in drm_usb_dev_path()
- intel: sync ADL-S PCI IDs with kernel
- amdgpu: add marketing names from 21.30
- amdgpu: add new marketing name
- intel: Sync pci ids
- update to 2.4.107
- amdgpu: Added product name for E9390,E9560 and E9565 dgpu
- ntel: Add support for ADLP
- update to 2.4.106
- Revert 'xf86drmMode: set FB_MODIFIERS flag when modifiers are supplied'
- update to 2.4.105

* Thu Jan 14 2021 tmb <tmb> 2.4.104-1.mga8
+ Revision: 1671768
- BR: python3-docutils
- update to 2.4.104

* Wed Nov 04 2020 tv <tv> 2.4.103-1.mga8
+ Revision: 1642582
- 2.4.103

* Sat Jun 06 2020 tv <tv> 2.4.102-1.mga8
+ Revision: 1590722
- 2.4.102

* Fri May 08 2020 tmb <tmb> 2.4.101-5.mga8
+ Revision: 1581652
- rebuild with gcc 10.1

* Wed Apr 29 2020 tmb <tmb> 2.4.101-4.mga8
+ Revision: 1573324
- replace 'fix realpath vs. firefox' quickfix with final upstreamed:
  'xf86drm: Check non-absolute path only for virtio based devices'

* Sat Apr 18 2020 tmb <tmb> 2.4.101-3.mga8
+ Revision: 1569121
- Fix firefox WebGL breakage (mga#26437)

* Sat Apr 04 2020 tv <tv> 2.4.101-1.mga8
+ Revision: 1564327
- 2.4.101
- drop Makefile patch now that autoconf support is dead

* Sun Feb 16 2020 umeabot <umeabot> 2.4.100-2.mga8
+ Revision: 1536357
- Mageia 8 Mass Rebuild

* Thu Oct 17 2019 tmb <tmb> 2.4.100-1.mga8
+ Revision: 1454248
- update to 2.4.100

* Fri Sep 27 2019 tmb <tmb> 2.4.99-3.mga8
+ Revision: 1447574
- add upstream fixes from git

* Tue Aug 13 2019 tmb <tmb> 2.4.99-2.mga8
+ Revision: 1429141
- rebuild with gcc 9.2

* Wed Jul 03 2019 tmb <tmb> 2.4.99-1.mga8
+ Revision: 1417869
- update to 2.4.99

* Mon Apr 22 2019 tv <tv> 2.4.98-1.mga7
+ Revision: 1394702
- 2.4.98

* Wed Apr 17 2019 umeabot <umeabot> 2.4.97-4.mga7
+ Revision: 1392711
- Rebuild with meson 0.50.1

* Thu Mar 28 2019 tmb <tmb> 2.4.97-3.mga7
+ Revision: 1380730
- add fixes from upstream

* Fri Feb 08 2019 tmb <tmb> 2.4.97-2.mga7
+ Revision: 1364308
- intel: sync i915_pciids.h with kernel

* Wed Jan 23 2019 tv <tv> 2.4.97-1.mga7
+ Revision: 1360380
- new release

* Wed Oct 17 2018 tv <tv> 2.4.96-1.mga7
+ Revision: 1321256
- new release

* Sat Oct 06 2018 tv <tv> 2.4.95-1.mga7
+ Revision: 1318142
- rediff patch
- new release

* Fri Aug 24 2018 tv <tv> 2.4.94-1.mga7
+ Revision: 1253848
- new release

* Mon Aug 13 2018 tmb <tmb> 2.4.93-1.mga7
+ Revision: 1251412
- rediff P1003
+ tv <tv>
- new release

* Tue Jun 05 2018 pterjan <pterjan> 2.4.92-6.mga7
+ Revision: 1234889
- Fix subpackages for aarch64

* Tue Jun 05 2018 pterjan <pterjan> 2.4.92-5.mga7
+ Revision: 1234882
- Fix file list on aarch64

* Thu May 10 2018 tv <tv> 2.4.92-4.mga7
+ Revision: 1228020
- new release

* Tue Apr 10 2018 neoclust <neoclust> 2.4.91-4.mga7
+ Revision: 1216962
- Add missing require on lib on ARM

* Wed Mar 21 2018 tmb <tmb> 2.4.91-3.mga7
+ Revision: 1211135
- update filelist, add etnaviv package for arm

* Wed Mar 21 2018 tmb <tmb> 2.4.91-2.mga7
+ Revision: 1211126
- rebuild for arm

* Fri Mar 09 2018 tv <tv> 2.4.91-1.mga7
+ Revision: 1207520
- new release

* Mon Feb 19 2018 tv <tv> 2.4.90-2.mga7
+ Revision: 1203282
- switch to meson

* Sat Feb 17 2018 tv <tv> 2.4.90-1.mga7
+ Revision: 1202046
- new release

* Mon Dec 18 2017 tv <tv> 2.4.89-1.mga7
+ Revision: 1183150
- new release

* Sat Nov 04 2017 tv <tv> 2.4.88-1.mga7
+ Revision: 1175863
- new release

* Wed Nov 01 2017 tv <tv> 2.4.87-1.mga7
+ Revision: 1175289
- new release

* Sat Oct 21 2017 tv <tv> 2.4.85-1.mga7
+ Revision: 1172977
- new release

* Fri Oct 13 2017 tv <tv> 2.4.84-1.mga7
+ Revision: 1171630
- new release

* Sat Sep 02 2017 tmb <tmb> 2.4.83-2.mga7
+ Revision: 1150728
- tests/amdgpu: add missing uve_ib.h header
- rebuild with new gcc/binutils
+ tv <tv>
- fixnew release

* Wed Jul 19 2017 tv <tv> 2.4.82-1.mga7
+ Revision: 1125260
- new release

* Tue Jun 06 2017 tmb <tmb> 2.4.81-1.mga6
+ Revision: 1107095
- 2.4.81

* Wed Apr 26 2017 tmb <tmb> 2.4.80-1.mga6
+ Revision: 1097541
- update to 2.4.80

* Wed Mar 01 2017 tv <tv> 2.4.75-1.mga6
+ Revision: 1088367
- new release

* Tue Nov 29 2016 tv <tv> 2.4.74-1.mga6
+ Revision: 1071018
- new release

* Thu Nov 17 2016 tv <tv> 2.4.73-2.mga6
+ Revision: 1068066
- BR pkgconfig(udev)
- new release

* Tue Oct 04 2016 tv <tv> 2.4.71-1.mga6
+ Revision: 1058318
- new release

* Sat Jul 23 2016 tmb <tmb> 2.4.70-1.mga6
+ Revision: 1043464
- update to 2.4.70

* Fri Jul 22 2016 tmb <tmb> 2.4.69-1.mga6
+ Revision: 1043045
- rebase P102, P500 to apply cleanly
- drm: drmGetDevice return correct device on multi GPU setups
- drm: fix drmFreeDevices memory leak on multi GPU setups
- update to 2.4.69

* Tue Jul 05 2016 tmb <tmb> 2.4.68-7.mga6
+ Revision: 1038917
- add more Kabylake ids

* Sun Jun 19 2016 tmb <tmb> 2.4.68-6.mga6
+ Revision: 1036810
- add fixes from upstream git

* Mon May 23 2016 tv <tv> 2.4.68-5.mga6
+ Revision: 1018112
- fix udev rules with FC

* Tue May 03 2016 tv <tv> 2.4.68-4.mga6
+ Revision: 1008895
- package tegra lib on ARM

* Mon May 02 2016 tv <tv> 2.4.68-3.mga6
+ Revision: 1008716
- fix utils' deps

* Mon May 02 2016 tv <tv> 2.4.68-2.mga6
+ Revision: 1008625
- BR pkgconfig(cunit) for amdgpu_test
- drop static sub package
- package utils
- enable more stuff on ARM
- BR systemd-devel instead of udev-devel
- adjust license
- remove temp BR on gcc5

* Mon May 02 2016 tv <tv> 2.4.68-1.mga6
+ Revision: 1008522
- drop mips patches
- new release

* Wed Feb 17 2016 tv <tv> 2.4.67-1.mga6
+ Revision: 963155
- drop merged patches
- 2.4.67

* Fri Jan 08 2016 tmb <tmb> 2.4.66-2.mga6
+ Revision: 920654
- intel/kbl: Add Kabylake PCI ids
- Fix memory leak with drmModeGetConnectorCurrent()

* Fri Jan 01 2016 luigiwalser <luigiwalser> 2.4.66-1.mga6
+ Revision: 917743
- 2.4.66

* Wed Sep 23 2015 blino <blino> 2.4.65-3.mga6
+ Revision: 882312
- package freedreno on ARM
- do not buildrequire valgrind on ARM/MIPS
- fix summary/description of AMDGPU packages

* Sun Sep 20 2015 tv <tv> 2.4.65-2.mga6
+ Revision: 881747
- make devel requires amdgpu lib

* Wed Sep 16 2015 tv <tv> 2.4.65-1.mga6
+ Revision: 879744
- new release

* Fri Aug 21 2015 tmb <tmb> 2.4.64-3.mga6
+ Revision: 867044
- rebuild with new gcc

* Thu Aug 20 2015 tmb <tmb> 2.4.64-2.mga6
+ Revision: 866690
- rebuild with gcc 5.2.1

* Tue Aug 18 2015 tv <tv> 2.4.64-1.mga6
+ Revision: 865708
- new release

* Tue Aug 18 2015 tmb <tmb> 2.4.63-2.mga6
+ Revision: 865424
- rebuild with new glibc

* Fri Aug 14 2015 tv <tv> 2.4.63-1.mga6
+ Revision: 864781
- adjust file list
- rediff patch0
- new release

* Wed Jul 01 2015 tv <tv> 2.4.62-1.mga6
+ Revision: 849233
- BR pkgconfig(valgrind)
- new release

* Sun Jun 21 2015 tv <tv> 2.4.61-1.mga6
+ Revision: 837869
- sync 2 patches with FC
- resync patch 500
- new release

* Wed Jan 21 2015 tmb <tmb> 2.4.59-1.mga5
+ Revision: 811712
- update to 2.4.59
- drop merged patches

* Mon Dec 01 2014 tmb <tmb> 2.4.58-3.mga5
+ Revision: 800208
- add initial Intel Skylake support
- intel: Fix SIGSEGV in libdrm for heigth = 0 and width = 0
- intel: Avoid overcounting fences when emitting self-referential relocs
- radeon: Always multiply pitch_bytes by nsamples, not by slice_pt

* Wed Oct 15 2014 umeabot <umeabot> 2.4.58-2.mga5
+ Revision: 751057
- Second Mageia 5 Mass Rebuild

* Wed Oct 01 2014 tmb <tmb> 2.4.58-1.mga5
+ Revision: 734458
- 2.4.58 (build fixes)
- more hw support

* Tue Sep 16 2014 umeabot <umeabot> 2.4.56-2.mga5
+ Revision: 681425
- Mageia 5 Mass Rebuild

* Thu Jul 31 2014 tv <tv> 2.4.56-1.mga5
+ Revision: 658394
- new release

* Fri Jul 25 2014 tv <tv> 2.4.55-1.mga5
+ Revision: 656544
- new release

* Thu May 22 2014 tmb <tmb> 2.4.54-5.mga5
+ Revision: 624861
- rebuild for llvm changes

* Wed May 21 2014 tmb <tmb> 2.4.54-3.mga5
+ Revision: 624800
- rebuild for fixed llvm

* Tue May 13 2014 tmb <tmb> 2.4.54-2.mga5
+ Revision: 622583
- rebuild with gcc 4.9

* Sat May 03 2014 tv <tv> 2.4.54-1.mga5
+ Revision: 619795
- new release

* Sun Apr 13 2014 tv <tv> 2.4.53-1.mga5
+ Revision: 613883
- new release

* Sat Feb 08 2014 tv <tv> 2.4.52-1.mga5
+ Revision: 585819
- new release

* Thu Jan 09 2014 tmb <tmb> 2.4.51-1.mga4
+ Revision: 566006
- update to 2.4.51
- drop merged patches

* Sun Jan 05 2014 tmb <tmb> 2.4.50-2.mga4
+ Revision: 564838
- radeon: avoid possible divide by 0 in surface manager
- radeon: fix sumo2 pci id
- drop P0008 (intel fence count fix), not accepted upstream

* Tue Dec 03 2013 tv <tv> 2.4.50-1.mga4
+ Revision: 554837
- new release

* Fri Nov 29 2013 tv <tv> 2.4.49-1.mga4
+ Revision: 554076
- new release

* Mon Nov 18 2013 tmb <tmb> 2.4.48-1.mga4
+ Revision: 551762
- 2.4.48:
  - radeon: hawaii support
  - intel: broadwell support
  - nouveau: prevent undefined behavior in nouveau_pushbuf_reloc with gcc-4.8

* Tue Oct 22 2013 umeabot <umeabot> 2.4.47-2.mga4
+ Revision: 541329
- Mageia 4 Mass Rebuild

* Sat Oct 12 2013 tv <tv> 2.4.47-1.mga4
+ Revision: 495593
- new release

* Sun Aug 11 2013 tmb <tmb> 2.4.46-2.mga4
+ Revision: 465404
- rebuild with new gcc

* Tue Jul 02 2013 tv <tv> 2.4.46-1.mga4
+ Revision: 449647
- new release

* Thu May 23 2013 tv <tv> 2.4.45-1.mga4
+ Revision: 424828
- new release

* Mon May 06 2013 tmb <tmb> 2.4.43-4.mga3
+ Revision: 412437
- Intel: Fix up fence counts (mga #9044, fdo #59771)

* Sat Apr 27 2013 tmb <tmb> 2.4.43-3.mga3
+ Revision: 411327
- radeon: add new SI and Richland pci ids

* Fri Apr 05 2013 tmb <tmb> 2.4.43-2.mga3
+ Revision: 408313
- fixes from upstream git
  makefiles: Add missing headers
  drm: Fix error message in drmWaitVBlank
  intel: Fix Haswell CRW PCI IDs
  intel-decode: Fix gen6 HIER_DEPTH_BUFFER decoding

* Sat Mar 30 2013 tmb <tmb> 2.4.43-1.mga3
+ Revision: 406617
- BR: docbook-xsl
- BR: cairo-devel, xsltproc
- 2.4.43 (bugfixes, Amd Richland APU support)

* Thu Feb 07 2013 tmb <tmb> 2.4.42-1.mga3
+ Revision: 395038
- disable man-pages temporarily
- 2.4.42: bugfixes, adds Amd Oland support

* Thu Jan 17 2013 tmb <tmb> 2.4.41-1.mga3
+ Revision: 388971
- 2.4.41 (bugfix release)

* Sun Jan 13 2013 tmb <tmb> 2.4.40-4.mga3
+ Revision: 380144
- install udev rules in correct place
- intel: Remove the fence count contributions when clearing relocs (P102, upstream)

* Sat Jan 12 2013 umeabot <umeabot> 2.4.40-2.mga3
+ Revision: 357012
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 07 2012 tv <tv> 2.4.40-1.mga3
+ Revision: 316246
- adjust file list
- drop linking patch (merged)
- new release

* Wed Sep 26 2012 rtp <rtp> 2.4.39-2.mga3
+ Revision: 298458
- fix file list
- enable omap and exynos on their arch.

* Fri Aug 24 2012 tv <tv> 2.4.39-1.mga3
+ Revision: 283761
- new release

* Sun Aug 12 2012 tv <tv> 2.4.38-1.mga3
+ Revision: 280968
- new release

* Thu Jul 19 2012 tmb <tmb> 2.4.37-4.mga3
+ Revision: 272373
- rebuild for new glibc

* Tue Jul 10 2012 anssi <anssi> 2.4.37-3.mga3
+ Revision: 269295
- re-add nouveau changes, mesa builds with them now
- drop obsolete unused nouveau configure option

* Sat Jun 30 2012 colin <colin> 2.4.37-2.mga3
+ Revision: 265573
- Back out nouveau changes to allow mesa rebuild

* Fri Jun 29 2012 tv <tv> 2.4.37-1.mga3
+ Revision: 265132
- new release

* Thu Jun 28 2012 tv <tv> 2.4.36-1.mga3
+ Revision: 264792
- new release

* Fri Jun 08 2012 tv <tv> 2.4.35-1.mga3
+ Revision: 257321
- new release

* Wed May 30 2012 tv <tv> 2.4.34-1.mga3
+ Revision: 249731
- fix file list
- nouveau major was bumped
- drop merged patches
- new release

* Tue Apr 03 2012 tmb <tmb> 2.4.33-1.mga2
+ Revision: 228055
- spec cleanups
- intel: add Ivy Bridge GT2 server variant (P1)
- update to 2.4.33 (needed for radeon backport)

* Wed Feb 08 2012 tv <tv> 2.4.31-1.mga2
+ Revision: 206565
- new release

* Fri Jan 06 2012 tv <tv> 2.4.30-1.mga2
+ Revision: 192736
- new release

* Tue Dec 13 2011 tv <tv> 2.4.29-1.mga2
+ Revision: 181219
- new release
- new release

* Tue Dec 06 2011 tmb <tmb> 2.4.27-2.mga2
+ Revision: 177789
- rebuild with gcc-4.6.2

* Sun Oct 30 2011 tv <tv> 2.4.27-1.mga2
+ Revision: 160173
- new release

* Thu Jun 09 2011 tv <tv> 2.4.26-1.mga2
+ Revision: 102708
- new release
- BuildRequires: libpciaccess-devel

* Fri Apr 15 2011 tv <tv> 2.4.25-1.mga1
+ Revision: 85649
- new release

* Thu Mar 03 2011 tv <tv> 2.4.24-1.mga1
+ Revision: 63431
- new release

* Sun Jan 23 2011 blino <blino> 2.4.23-2.mga1
+ Revision: 35365
- rebuild with udev

* Tue Jan 11 2011 dmorgan <dmorgan> 2.4.23-1.mga1
+ Revision: 5564
- Disable udev for now
+ pterjan <pterjan>
- Drop obsolete scriptlets
- imported package libdrm


* Fri Dec 17 2010 Colin Guthrie <cguthrie@mandriva.org> 2.4.23-1mdv2011.0
+ Revision: 622605
- New version: 2.4.23

* Wed Sep 29 2010 Colin Guthrie <cguthrie@mandriva.org> 2.4.22-1mdv2011.0
+ Revision: 582082
- New version: 2.4.22

* Fri Sep 24 2010 Colin Guthrie <cguthrie@mandriva.org> 2.4.21-2mdv2011.0
+ Revision: 580864
- Add upstream patch for to allow new intel driver to compile.

* Tue Jul 20 2010 Thierry Vignaud <tv@mandriva.org> 2.4.21-1mdv2011.0
+ Revision: 555148
- new release

* Wed May 12 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 2.4.20-2mdv2010.1
+ Revision: 544575
- Add upstream patch to fix memory corruption for intel

* Sat Apr 03 2010 Anssi Hannula <anssi@mandriva.org> 2.4.20-1mdv2010.1
+ Revision: 530881
- new version 2.4.20
  o drm headers moved to /usr/include/libdrm; software depending on
    libdrm that use pkgconfig should not need any changes
- remove upstream patches
- remove now unneeded configure option for radeon experimental api

* Tue Mar 23 2010 Anssi Hannula <anssi@mandriva.org> 2.4.19-3mdv2010.1
+ Revision: 526934
- add nouveau and intel fixes from git master

* Wed Mar 17 2010 Anssi Hannula <anssi@mandriva.org> 2.4.19-2mdv2010.1
+ Revision: 523324
- unrevert nouveau ABI changes
- add nouveau fixes from git

* Thu Mar 04 2010 Colin Guthrie <cguthrie@mandriva.org> 2.4.19-1mdv2010.1
+ Revision: 514351
- Require libkms in the devel package.
- Fix nouveau revert patch to apply (partial application upstream)
- Add libkms subpackage
- Fix linking (patch from xorg ML)

  + Thierry Vignaud <tv@mandriva.org>
    - new release

* Fri Feb 19 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 2.4.18-1mdv2010.1
+ Revision: 508129
- New version: 2.4.18
  Remove applied patches (nouveau and intel cherry-picks)
  Temporarily revert 2 nouveau commits that break the abi

* Fri Feb 12 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 2.4.17-6mdv2010.1
+ Revision: 505049
- Another cherry-pick for intel to prevent hangs and oops

* Wed Feb 10 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 2.4.17-5mdv2010.1
+ Revision: 503837
- Cherry-pick intel upstream commit to prevent hangups (fd.o #25475)

* Sat Feb 06 2010 Anssi Hannula <anssi@mandriva.org> 2.4.17-4mdv2010.1
+ Revision: 501482
- update libdrm_nouveau to current git

* Fri Jan 29 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 2.4.17-3mdv2010.1
+ Revision: 498103
- Add 2 patches to fix intel bugs (Xorg crash) reported on IRC

* Wed Jan 06 2010 Anssi Hannula <anssi@mandriva.org> 2.4.17-2mdv2010.1
+ Revision: 486769
- update nouveau part to libdrm git (4 commits)

* Mon Dec 21 2009 Anssi Hannula <anssi@mandriva.org> 2.4.17-1mdv2010.1
+ Revision: 480863
- new release

* Fri Dec 04 2009 Thierry Vignaud <tv@mandriva.org> 2.4.16-1mdv2010.1
+ Revision: 473502
- new release
- rediff patches for path changes

* Mon Nov 09 2009 Thierry Vignaud <tv@mandriva.org> 2.4.15-0.1mdv2010.1
+ Revision: 463428
- new release

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 2.4.14-2mdv2010.0
+ Revision: 449859
- add mips patches (from Arnaud Patard)

* Wed Sep 23 2009 Thierry Vignaud <tv@mandriva.org> 2.4.14-1mdv2010.0
+ Revision: 447709
- new release

* Thu Sep 17 2009 Thierry Vignaud <tv@mandriva.org> 2.4.13-2mdv2010.0
+ Revision: 443997
- radeon: fix 32/64 bit issue with sign extension

* Mon Aug 31 2009 Thierry Vignaud <tv@mandriva.org> 2.4.13-1mdv2010.0
+ Revision: 422872
- new release

* Sun Aug 02 2009 Anssi Hannula <anssi@mandriva.org> 2.4.12-2mdv2010.0
+ Revision: 407529
- update nouveau library to git snapshot

* Fri Jul 24 2009 Anssi Hannula <anssi@mandriva.org> 2.4.12-1mdv2010.0
+ Revision: 399497
- new version 2.4.12
- fix underlinking in libdrm_intel (intel-underlinking.patch)
- drop radeon patch, applied upstream (with configure option)
- remove unused patches

* Wed May 20 2009 Colin Guthrie <cguthrie@mandriva.org> 2.4.11-1mdv2010.0
+ Revision: 378087
- New version: 2.4.11
- BuildRequire udev-devel
- Use %%apply_patches

* Sun May 10 2009 Colin Guthrie <cguthrie@mandriva.org> 2.4.9-3mdv2010.0
+ Revision: 374013
- Include a couple of intel fixes from upstream
- Remove old file not referenced in SPEC

* Wed Apr 22 2009 Frederic Crozat <fcrozat@mandriva.com> 2.4.9-2mdv2009.1
+ Revision: 368623
- Increase timeout for dri detection, in speedboot mode only (Mdv bug #49490)

* Thu Apr 16 2009 Colin Guthrie <cguthrie@mandriva.org> 2.4.9-1mdv2009.1
+ Revision: 367601
- New version: 2.4.9
- Drop nouveau headers patch (fixed upstream)

* Fri Apr 10 2009 Anssi Hannula <anssi@mandriva.org> 2.4.9-0.1mdv2009.1
+ Revision: 365759
- obsolete drm-nouveau-devel in correct package

* Wed Apr 08 2009 Frederic Crozat <fcrozat@mandriva.com> 2.4.5-8mdv2009.1
+ Revision: 365194
- Enable patch 5 again, but use upstream timing

* Wed Apr 08 2009 Frederic Crozat <fcrozat@mandriva.com> 2.4.5-7mdv2009.1
+ Revision: 365159
- Disable patch6, it is causing 1min timeout on some systems

* Wed Apr 08 2009 Frederic Crozat <fcrozat@mandriva.com> 2.4.5-6mdv2009.1
+ Revision: 365113
- Patch5: improve wait on dri devices when system is busy (Mdv bug #49490)

* Tue Mar 31 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.5-5mdv2009.1
+ Revision: 362770
- Remove bad worded and unecessary /etc/modprobe.d/i915modeset
  (also it prevents passing custom options to i915 using modprobe)

* Mon Mar 02 2009 Anssi Hannula <anssi@mandriva.org> 2.4.5-4mdv2009.1
+ Revision: 347410
- enable experimental nouveau api
- add missing nouveau headers (missing-nouveau-headers.patch)

* Mon Mar 02 2009 Anssi Hannula <anssi@mandriva.org> 2.4.5-3mdv2009.1
+ Revision: 347380
- fix requires of devel package

* Sun Mar 01 2009 Anssi Hannula <anssi@mandriva.org> 2.4.5-2mdv2009.1
+ Revision: 346373
- own /usr/include/drm
- split libdrm_intel and libdrm_radeon, their major differs
- fix group
- drop duplicate requires
- ensure major correctness
- devel obsoletes drm-nouveau-devel

* Wed Feb 25 2009 Colin Guthrie <cguthrie@mandriva.org> 2.4.5-1mdv2009.1
+ Revision: 344967
- New version: 2.4.5
- Drop upstream patches

* Tue Feb 17 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 2.4.4-2mdv2009.1
+ Revision: 342152
- Cherry pick "intel: libdrm support for fence management in execbuf" from master.
  This is needed to enable tiled rendering on intel pre-i965 hardware (cf.
  svn revision 342151 for intel driver).

* Thu Jan 15 2009 Colin Guthrie <cguthrie@mandriva.org> 2.4.4-1mdv2009.1
+ Revision: 329701
- New version: 2.4.4

* Tue Dec 30 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.3-2mdv2009.1
+ Revision: 321372
- Fix bogus provides

* Tue Dec 30 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.3-1mdv2009.1
+ Revision: 321331
- Update to 2.4.3
- Enable udev support
- Liberate patches from Fedora
- Install udev rules for permissions
- Allow activation of kernel modesetting via kernel cmdline

* Sun Nov 16 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.1-9mdv2009.1
+ Revision: 303789
- Conflicts with kernel-headers package because of headers being
  provided again by libdrm.

* Thu Nov 13 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.1-8mdv2009.1
+ Revision: 302923
- Install all headers (the ones from kernel-headers are, like, so last season)

* Tue Nov 04 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.1-7mdv2009.1
+ Revision: 299839
- Rebuild because of eaten static-devel package in latest submit.

* Mon Nov 03 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.1-6mdv2009.1
+ Revision: 299592
- libdrm-devel: remove files provided by kernel-headers.

* Mon Nov 03 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.1-5mdv2009.1
+ Revision: 299588
- Fix buildrequires version match for kernel-headers.

* Mon Nov 03 2008 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 2.4.1-4mdv2009.1
+ Revision: 299580
- Rebuild with kernel-headers 2.6.27.4-1mnb2

* Sun Nov 02 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.1-3mdv2009.1
+ Revision: 299245
- Unrevert the symbol change commit (intel driver just needs rebuild)

* Sat Nov 01 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.1-2mdv2009.1
+ Revision: 299165
- Fix a crash by reverting upstream commit (for now)

* Sat Nov 01 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.1-1mdv2009.1
+ Revision: 299139
- New version: 2.4.1

* Mon Oct 27 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.0-2mdv2009.1
+ Revision: 297741
- Prevent a lockup in intel_bufmgr_fake

* Tue Oct 21 2008 Colin Guthrie <cguthrie@mandriva.org> 2.4.0-1mdv2009.1
+ Revision: 295881
- Add missing buildrequire for libpthread-stubs
- New version: 2.4.0

* Thu Jul 24 2008 Ander Conselvan de Oliveira <ander@mandriva.com> 2.3.1-1mdv2009.0
+ Revision: 245954
- Update to verseion 2.3.1

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 2.3.0-8mdv2009.0
+ Revision: 222535
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Paulo Andrade <pcpa@mandriva.com.br>
    - Revert build requires.

* Mon Jan 14 2008 Paulo Andrade <pcpa@mandriva.com.br> 2.3.0-7mdv2008.1
+ Revision: 151897
- Update BuildRequires and rebuild.
  Also disable patch1 as it is being used just to "document" functions called
  from the X Server.

* Sun Jan 13 2008 Thierry Vignaud <tv@mandriva.org> 2.3.0-6mdv2008.1
+ Revision: 150691
- BuildRequires x11-proto-devel for X11/Xfuncproto.h
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Paulo Andrade <pcpa@mandriva.com.br>
    - Initial listing of symbols required by the ati driver. This is for now a noop
      patch as libraries at first will have all symbols visible.

* Fri Aug 31 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.0-4mdv2008.0
+ Revision: 76972
- cleanup borked deps

* Fri Aug 31 2007 Oden Eriksson <oeriksson@mandriva.com> 2.3.0-3mdv2008.0
+ Revision: 76831
- new devel name


* Wed Mar 21 2007 Gustavo Pichorim Boiko <boiko@mandriva.com> 2.3.0-2mdv2007.1
+ Revision: 147232
- When checking wheter to change owner or not, serv_group is unsigned.

* Tue Nov 14 2006 Thierry Vignaud <tvignaud@mandriva.com> 2.3.0-1mdv2007.1
+ Revision: 84141
- new release

* Thu Jun 29 2006 Gustavo Pichorim Boiko <boiko@mandriva.com> 2.0.2-1mdv2007.0
+ Revision: 38128
- new upstream version (2.0.2):
   * Updated kernel DRM headers
- rebuild to fix cooker uploading
- X11R7.1
- renaming the specfile as well
- renaming the package to its right name (without the soname)
- do not use soname in the srpm
- Adding X.org 7.0 to the repository

  + Frederic Crozat <fcrozat@mandriva.com>
    - Patch0: do not change permission if not requested
    - call ldconfig on lib package install/removal

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix license

